SortItem class

An id/value pair for collation sorting.

Constructors

SortItem({required String id, required String value})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
Opaque identifier returned in the sorted result.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
String whose collation order determines the sort position.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override