LinuxDelegate class

Inheritance

Constructors

LinuxDelegate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init(SortOptions options) Future<void>
Initializes the delegate with platform-specific options.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sort(List<SortItem> items, {SortDirection? direction, Locale? locale}) FutureOr<List<SortItem>>
Sorts items by collation order.
override
sortWith(List<SortItem> items, {Locale? locale, SortDirection? direction, CollatorStrength? strength, CollatorDecomposition? decomposition, bool? numeric}) List<SortItem>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited