WindowsCollationLoader class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
isInitialized
→ bool
-
Whether init has completed successfully.
no setteroverride
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
collator(String? localeName, {bool numeric = true, int? strength, int? decomposition})
→ IcuCollator
-
Returns a new collator for
localeName.
override
-
dispose()
→ void
-
Releases the library handle.
override
-
init()
→ Future<void>
-
Resolves the native ICU library and its function pointers.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited